==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/subscription/kotlin/inputs/PutAliasRequestPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.subscription.kotlin.inputs

import com.pulumi.azurenative.subscription.inputs.PutAliasRequestPropertiesArgs.builder
import com.pulumi.azurenative.subscription.kotlin.enums.Workload
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Put subscription properties.
 * @property additionalProperties Put alias request additional properties.
 * @property billingScope Billing scope of the subscription.
 * For CustomerLed and FieldLed - /billingAccounts/{billingAccountName}/billingProfiles/{billingProfileName}/invoiceSections/{invoiceSectionName}
 * For PartnerLed - /billingAccounts/{billingAccountName}/customers/{customerName}
 * For Legacy EA - /billingAccounts/{billingAccountName}/enrollmentAccounts/{enrollmentAccountName}
 * @property displayName The friendly name of the subscription.
 * @property resellerId Reseller Id
 * @property subscriptionId This parameter can be used to create alias for existing subscription Id
 * @property workload The workload type of the subscription. It can be either Production or DevTest.
 */
public data class PutAliasRequestPropertiesArgs(
    public val additionalProperties: Output<PutAliasRequestAdditionalPropertiesArgs>? = null,
    public val billingScope: Output<String>? = null,
    public val displayName: Output<String>? = null,
    public val resellerId: Output<String>? = null,
    public val subscriptionId: Output<String>? = null,
    public val workload: Output<Either<String, Workload>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.subscription.inputs.PutAliasRequestPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.subscription.inputs.PutAliasRequestPropertiesArgs =
        com.pulumi.azurenative.subscription.inputs.PutAliasRequestPropertiesArgs.builder()
            .additionalProperties(
                additionalProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .billingScope(billingScope?.applyValue({ args0 -> args0 }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .resellerId(resellerId?.applyValue({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.applyValue({ args0 -> args0 }))
            .workload(
                workload?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [PutAliasRequestPropertiesArgs].
 */
@PulumiTagMarker
public class PutAliasRequestPropertiesArgsBuilder internal constructor() {
    private var additionalProperties: Output<PutAliasRequestAdditionalPropertiesArgs>? = null

    private var billingScope: Output<String>? = null

    private var displayName: Output<String>? = null

    private var resellerId: Output<String>? = null

    private var subscriptionId: Output<String>? = null

    private var workload: Output<Either<String, Workload>>? = null

    /**
     * @param value Put alias request additional properties.
     */
    @JvmName("ysesecngbioomalk")
    public suspend
    fun additionalProperties(`value`: Output<PutAliasRequestAdditionalPropertiesArgs>) {
        this.additionalProperties = value
    }

    /**
     * @param value Billing scope of the subscription.
     * For CustomerLed and FieldLed - /billingAccounts/{billingAccountName}/billingProfiles/{billingProfileName}/invoiceSections/{invoiceSectionName}
     * For PartnerLed - /billingAccounts/{billingAccountName}/customers/{customerName}
     * For Legacy EA - /billingAccounts/{billingAccountName}/enrollmentAccounts/{enrollmentAccountName}
     */
    @JvmName("wokbforcpdqbiqwi")
    public suspend fun billingScope(`value`: Output<String>) {
        this.billingScope = value
    }

    /**
     * @param value The friendly name of the subscription.
     */
    @JvmName("kibfxoerehebmoma")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value Reseller Id
     */
    @JvmName("dqyayimqxjwwhsfs")
    public suspend fun resellerId(`value`: Output<String>) {
        this.resellerId = value
    }

    /**
     * @param value This parameter can be used to create alias for existing subscription Id
     */
    @JvmName("mwtktlpppengvnma")
    public suspend fun subscriptionId(`value`: Output<String>) {
        this.subscriptionId = value
    }

    /**
     * @param value The workload type of the subscription. It can be either Production or DevTest.
     */
    @JvmName("flwdcxpcrxwlgfmf")
    public suspend fun workload(`value`: Output<Either<String, Workload>>) {
        this.workload = value
    }

    /**
     * @param value Put alias request additional properties.
     */
    @JvmName("qddwbniqnfhwnuib")
    public suspend fun additionalProperties(`value`: PutAliasRequestAdditionalPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalProperties = mapped
    }

    /**
     * @param argument Put alias request additional properties.
     */
    @JvmName("hpruvldkwqetyexs")
    public suspend
    fun additionalProperties(argument: suspend PutAliasRequestAdditionalPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PutAliasRequestAdditionalPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.additionalProperties = mapped
    }

    /**
     * @param value Billing scope of the subscription.
     * For CustomerLed and FieldLed - /billingAccounts/{billingAccountName}/billingProfiles/{billingProfileName}/invoiceSections/{invoiceSectionName}
     * For PartnerLed - /billingAccounts/{billingAccountName}/customers/{customerName}
     * For Legacy EA - /billingAccounts/{billingAccountName}/enrollmentAccounts/{enrollmentAccountName}
     */
    @JvmName("nlfuatfvfivdaial")
    public suspend fun billingScope(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.billingScope = mapped
    }

    /**
     * @param value The friendly name of the subscription.
     */
    @JvmName("ywmqwnfebmmkqhop")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value Reseller Id
     */
    @JvmName("jjyeproqsiktwmtq")
    public suspend fun resellerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resellerId = mapped
    }

    /**
     * @param value This parameter can be used to create alias for existing subscription Id
     */
    @JvmName("bacvuxjuwrwnayio")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionId = mapped
    }

    /**
     * @param value The workload type of the subscription. It can be either Production or DevTest.
     */
    @JvmName("pkprfsuhlobijgwn")
    public suspend fun workload(`value`: Either<String, Workload>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workload = mapped
    }

    /**
     * @param value The workload type of the subscription. It can be either Production or DevTest.
     */
    @JvmName("lrcwwjortwgnbnrk")
    public fun workload(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Workload>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workload = mapped
    }

    /**
     * @param value The workload type of the subscription. It can be either Production or DevTest.
     */
    @JvmName("jrcyqughepyuijig")
    public fun workload(`value`: Workload) {
        val toBeMapped = Either.ofRight<String, Workload>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workload = mapped
    }

    internal fun build(): PutAliasRequestPropertiesArgs = PutAliasRequestPropertiesArgs(
        additionalProperties = additionalProperties,
        billingScope = billingScope,
        displayName = displayName,
        resellerId = resellerId,
        subscriptionId = subscriptionId,
        workload = workload,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/subscription/kotlin/inputs/PutAliasRequestPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.subscription.kotlin.inputs

import com.pulumi.azurenative.subscription.inputs.PutAliasRequestPropertiesArgs.builder
import com.pulumi.azurenative.subscription.kotlin.enums.Workload
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Put subscription properties.
 * @property additionalProperties Put alias request additional properties.
 * @property billingScope Billing scope of the subscription.
 * For CustomerLed and FieldLed - /billingAccounts/{billingAccountName}/billingProfiles/{billingProfileName}/invoiceSections/{invoiceSectionName}
 * For PartnerLed - /billingAccounts/{billingAccountName}/customers/{customerName}
 * For Legacy EA - /billingAccounts/{billingAccountName}/enrollmentAccounts/{enrollmentAccountName}
 * @property displayName The friendly name of the subscription.
 * @property resellerId Reseller Id
 * @property subscriptionId This parameter can be used to create alias for existing subscription Id
 * @property workload The workload type of the subscription. It can be either Production or DevTest.
 */
public data class PutAliasRequestPropertiesArgs(
    public val additionalProperties: Output<PutAliasRequestAdditionalPropertiesArgs>? = null,
    public val billingScope: Output<String>? = null,
    public val displayName: Output<String>? = null,
    public val resellerId: Output<String>? = null,
    public val subscriptionId: Output<String>? = null,
    public val workload: Output<Either<String, Workload>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.subscription.inputs.PutAliasRequestPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.subscription.inputs.PutAliasRequestPropertiesArgs =
        com.pulumi.azurenative.subscription.inputs.PutAliasRequestPropertiesArgs.builder()
            .additionalProperties(
                additionalProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .billingScope(billingScope?.applyValue({ args0 -> args0 }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .resellerId(resellerId?.applyValue({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.applyValue({ args0 -> args0 }))
            .workload(
                workload?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [PutAliasRequestPropertiesArgs].
 */
@PulumiTagMarker
public class PutAliasRequestPropertiesArgsBuilder internal constructor() {
    private var additionalProperties: Output<PutAliasRequestAdditionalPropertiesArgs>? = null

    private var billingScope: Output<String>? = null

    private var displayName: Output<String>? = null

    private var resellerId: Output<String>? = null

    private var subscriptionId: Output<String>? = null

    private var workload: Output<Either<String, Workload>>? = null

    /**
     * @param value Put alias request additional properties.
     */
    @JvmName("dbtyiimrjdxtjqip")
    public suspend
    fun additionalProperties(`value`: Output<PutAliasRequestAdditionalPropertiesArgs>) {
        this.additionalProperties = value
    }

    /**
     * @param value Billing scope of the subscription.
     * For CustomerLed and FieldLed - /billingAccounts/{billingAccountName}/billingProfiles/{billingProfileName}/invoiceSections/{invoiceSectionName}
     * For PartnerLed - /billingAccounts/{billingAccountName}/customers/{customerName}
     * For Legacy EA - /billingAccounts/{billingAccountName}/enrollmentAccounts/{enrollmentAccountName}
     */
    @JvmName("dfdpxpbhhpqyunmp")
    public suspend fun billingScope(`value`: Output<String>) {
        this.billingScope = value
    }

    /**
     * @param value The friendly name of the subscription.
     */
    @JvmName("fxgawhbrkaqgptou")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value Reseller Id
     */
    @JvmName("ndscnuwdcmkgphmu")
    public suspend fun resellerId(`value`: Output<String>) {
        this.resellerId = value
    }

    /**
     * @param value This parameter can be used to create alias for existing subscription Id
     */
    @JvmName("iimtpwvnpaopkilr")
    public suspend fun subscriptionId(`value`: Output<String>) {
        this.subscriptionId = value
    }

    /**
     * @param value The workload type of the subscription. It can be either Production or DevTest.
     */
    @JvmName("halmsrntkayxkvhn")
    public suspend fun workload(`value`: Output<Either<String, Workload>>) {
        this.workload = value
    }

    /**
     * @param value Put alias request additional properties.
     */
    @JvmName("kqdwjfaujnnnswso")
    public suspend fun additionalProperties(`value`: PutAliasRequestAdditionalPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalProperties = mapped
    }

    /**
     * @param argument Put alias request additional properties.
     */
    @JvmName("ucumporictbbonjw")
    public suspend
    fun additionalProperties(argument: suspend PutAliasRequestAdditionalPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PutAliasRequestAdditionalPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.additionalProperties = mapped
    }

    /**
     * @param value Billing scope of the subscription.
     * For CustomerLed and FieldLed - /billingAccounts/{billingAccountName}/billingProfiles/{billingProfileName}/invoiceSections/{invoiceSectionName}
     * For PartnerLed - /billingAccounts/{billingAccountName}/customers/{customerName}
     * For Legacy EA - /billingAccounts/{billingAccountName}/enrollmentAccounts/{enrollmentAccountName}
     */
    @JvmName("dpjdipeqfjsbjgxq")
    public suspend fun billingScope(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.billingScope = mapped
    }

    /**
     * @param value The friendly name of the subscription.
     */
    @JvmName("eeetceboiofngtuc")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value Reseller Id
     */
    @JvmName("iiykkrcanbwtsbov")
    public suspend fun resellerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resellerId = mapped
    }

    /**
     * @param value This parameter can be used to create alias for existing subscription Id
     */
    @JvmName("omavygqqipewdvgs")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionId = mapped
    }

    /**
     * @param value The workload type of the subscription. It can be either Production or DevTest.
     */
    @JvmName("twwtehentwxsmatd")
    public suspend fun workload(`value`: Either<String, Workload>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workload = mapped
    }

    /**
     * @param value The workload type of the subscription. It can be either Production or DevTest.
     */
    @JvmName("xxsorabfinbejunj")
    public fun workload(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Workload>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workload = mapped
    }

    /**
     * @param value The workload type of the subscription. It can be either Production or DevTest.
     */
    @JvmName("ysbwqjttxcavepvf")
    public fun workload(`value`: Workload) {
        val toBeMapped = Either.ofRight<String, Workload>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workload = mapped
    }

    internal fun build(): PutAliasRequestPropertiesArgs = PutAliasRequestPropertiesArgs(
        additionalProperties = additionalProperties,
        billingScope = billingScope,
        displayName = displayName,
        resellerId = resellerId,
        subscriptionId = subscriptionId,
        workload = workload,
    )
}
